<?php
$single_product_gallery_settings = rigid_get_option('single_product_gallery_settings',array(
	'zoom' => '1',
	'lightbox' => '1'
));

// Woocommerce specific functions
// Add support for woocommerce
add_theme_support('woocommerce' );
if($single_product_gallery_settings['zoom']) {
	add_theme_support( 'wc-product-gallery-zoom' );
}
if($single_product_gallery_settings['lightbox']) {
	add_theme_support( 'wc-product-gallery-lightbox' );
}
add_theme_support( 'wc-product-gallery-slider' );

/** @var $product WC_Product */

// Disable WooCommerce styles
if (version_compare(WOOCOMMERCE_VERSION, "2.1") >= 0) {
	add_filter('woocommerce_enqueue_styles', '__return_false');
} else {
	define('WOOCOMMERCE_USE_CSS', false);
}

add_filter( 'woocommerce_breadcrumb_defaults', 'rigid_woocommerce_breadcrumb_defaults' );
if ( ! function_exists( 'rigid_woocommerce_breadcrumb_defaults' ) ) {
	function rigid_woocommerce_breadcrumb_defaults( $args ) {
		$args['delimiter']   = ' <span class="rigid-breadcrumb-delimiter">/</span> ';
		$args['wrap_before'] = '<div class="breadcrumb">';
		$args['wrap_after']  = '</div>';

		return $args;
	}
}

add_filter('woocommerce_breadcrumb_home_url', 'rigid_woocommerce_breadcrumb_home_url');
if ( ! function_exists( 'rigid_woocommerce_breadcrumb_home_url' ) ) {
	function rigid_woocommerce_breadcrumb_home_url( $home_url ) {
        return rigid_wpml_get_home_url();
	}
}

add_action( 'woocommerce_get_breadcrumb', 'rigid_woocommerce_get_breadcrumb', 20, 2 );
if ( ! function_exists( 'rigid_woocommerce_get_breadcrumb' ) ) {
	/**
     * Hook into 'woocommerce_get_breadcrumb' in order to
     * add path for the MVX specific endpoints for vendor policies
     * and reviews
     *
	 * @param $crumbs
	 * @param $wc_breadcrumb
	 *
	 * @return array|mixed
	 */
	function rigid_woocommerce_get_breadcrumb( $crumbs, $wc_breadcrumb ) {
		if ( class_exists( 'MVX' ) ) {
			$vendor_query_var   = get_query_var( 'vendor', false );
			$reviews_query_var  = get_query_var( 'reviews', false ) === 'true';
			$policies_query_var = get_query_var( 'policies', false ) === 'true';

			if ( $vendor_query_var && ( $reviews_query_var || $policies_query_var ) ) {
				if ( empty( $crumbs[1][0] ) ) {
					unset( $crumbs[1] );
				}
				$crumbs[] = array( esc_html__( 'Vendor', 'rigid' ), '' );
				$crumbs[] = array( esc_html( get_query_var( 'vendor' ) ), '' );
				if ( $reviews_query_var ) {
					$crumbs[] = array( esc_html__( 'Reviews', 'rigid' ), '' );
				} elseif ( $policies_query_var ) {
					$crumbs[] = array( esc_html__( 'Policies', 'rigid' ), '' );
				}
			}
		}

		return array_values( $crumbs );
	}
}

// removed breadcrumb from hook and call explicitly in wrapper-start
remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20);

/**
 * Display the image part of the product in loop
 *
 * Takes into account product_hover_onproduct theme option
 */
remove_action('woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10);
remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5);

remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);
add_filter('woocommerce_before_shop_loop_item', 'rigid_shop_loop_image', 10);

if ( ! function_exists( 'rigid_shop_loop_image' ) ) {

	function rigid_shop_loop_image() {
		global $post;
		echo '<div class="image">';

		?>

        <a href="<?php the_permalink(); ?>">
			<?php woocommerce_template_loop_product_thumbnail(); ?>
			<?php
			$second_image = rigid_get_second_product_image_id( $post );
			// If we have swap image enabled and second image:
			if ( rigid_get_option( 'product_hover_onproduct' ) == 'rigid-prodhover-swap' && $second_image ):
				?>
				<?php
				$image_size = apply_filters( 'single_product_archive_thumbnail_size', 'shop_catalog' );

				$props = wc_get_product_attachment_props( $second_image, $post );
				echo wp_get_attachment_image( $second_image, $image_size, false, array(
					'title' => $props['title'],
					'alt'   => $props['alt']
				) );
				?>
			<?php endif; ?>
        </a>
        <!-- Small countdown -->
		<?php rigid_shop_sale_countdown() ?>
		<?php
		echo '</div>';
	}

}

if ( ! function_exists( 'rigid_get_second_product_image_id' ) ) {
	/**
	 * Returns the second product image ID (if any)
	 * Else returns false
	 *
	 * @param mixed $post Post object or post ID of the product.
	 *
	 * @return int|bool false if no second image OR the attachment ID of the image
	 */
	function rigid_get_second_product_image_id( $post ) {
		$product  = wc_get_product( $post );
		$imageIds = $product->get_gallery_image_ids();

		if ( array_key_exists( 0, $imageIds ) ) {
			return $imageIds[0];
		}

		return false;
	}
}

/**
 * Checks if the product is in the new period
 *
 * @param WC_Product $product
 * @return boolean
 */
if (!function_exists('rigid_is_product_new')) {

	function rigid_is_product_new($product) {
		/** @var $product WC_Product */

		$days_product_is_new = rigid_get_option('new_label_period', 45);

		if($days_product_is_new != 0) {
			$post_date_dt = date_create( $product->get_date_created() );
			$curr_date_dt = date_create( 'now' );
			$post_date_ts = $post_date_dt->format( 'Y-m-d' );
			$curr_date_ts = $curr_date_dt->format( 'Y-m-d' );

			$diff = abs( strtotime( $post_date_ts ) - strtotime( $curr_date_ts ) );
			$diff /= 3600 * 24;

			if ( $diff < $days_product_is_new ) {
				return true;
			}
		}

		return false;
	}

}

/**
 * Returns the "not sale" price.
 * Used by rigid_get_product_saving()
 *
 * @param WC_Product $product
 * @return type
 */
if (!function_exists('rigid_get_product_not_sale_price')) {

	function rigid_get_product_not_sale_price($product) {
		/** @var $product WC_Product */
		if($product->is_type('variable')) {
			return $product->get_variation_regular_price('min');
		} else {
			return $product->get_regular_price();
		}
	}

}

if ( ! function_exists( 'rigid_get_product_sale_price' ) ) {
	function rigid_get_product_sale_price( $product ) {
		/** @var $product WC_Product */
		if ( $product->is_type( 'variable' ) ) {
			return $product->get_variation_sale_price();
		} else {
			return $product->get_price();
		}
	}
}

/**
 * Gets product saving
 *
 * @param WC_Product $product
 * @return type
 */
if (!function_exists('rigid_get_product_saving')) {

	function rigid_get_product_saving($product) {
		/** @var $product WC_Product */
		if ($product->is_on_sale()) {
			$sale_price = rigid_get_product_sale_price($product);
			$not_sale_price = rigid_get_product_not_sale_price($product);

			$saving = 0;
			if($not_sale_price) {
				$saving = 100 - $sale_price / $not_sale_price * 100;
			}

			return round($saving);
		}
	}

}

// Unload PrettyPhoto init for Woocommerce only
add_action('wp_enqueue_scripts', 'rigid_remove_wc_prettyphoto');

if (!function_exists('rigid_remove_wc_prettyphoto')) {

	function rigid_remove_wc_prettyphoto() {
		wp_dequeue_script('prettyPhoto-init');
	}

}

// remove result count showing on top of category
remove_action('woocommerce_before_shop_loop', 'woocommerce_result_count', 20);

// Display content holder
add_action('woocommerce_before_shop_loop', 'rigid_add_content_holder', 10);
if (!function_exists('rigid_add_content_holder')) {

	function rigid_add_content_holder() {

		echo '<div class="content_holder">';

		$style_class = 'columns-' . rigid_get_option('category_columns_num');

		if (rigid_get_option('enable_shop_cat_carousel')) {
			// owl carousel
			wp_localize_script('rigid-libs-config', 'rigid_owl_carousel_cat', array(
					'columns' => esc_js(rigid_get_option('category_columns_num'))
			));

			$style_class = 'owl-carousel rigid-owl-carousel';
		}

		$display_type = woocommerce_get_loop_display_mode();
		if ( 'subcategories' === $display_type || 'both' === $display_type ) {
			$before_categories_html = '<div class="rigid_woo_categories_shop woocommerce ' . esc_attr( $style_class ) . '">';
			echo woocommerce_maybe_show_product_subcategories($before_categories_html);
			echo '</div>';
		}

		if (rigid_get_option('show_refine_area') && woocommerce_products_will_display()) {
			echo '<div class="box-sort-filter'.(is_active_sidebar('rigid_product_filters_sidebar') ? ' rigid-product-filters-has-widgets' : '' ).'">';
			echo '<h2 class="heading-title">' . esc_html__('Refine Products', 'rigid') . '</h2>';
			echo '<div class="product-filter">';
			if(is_active_sidebar('rigid_product_filters_sidebar')) {
				echo '<a title="' . esc_attr__( 'More Filters', 'rigid' ) . '" class="rigid-filter-widgets-triger" href="#">' . esc_html__('Filter', 'rigid') . '</a>';
			}
		}
	}

}

add_filter( 'woocommerce_price_filter_widget_step', 'rigid_set_price_filter_widget_step' );
if ( ! function_exists( 'rigid_set_price_filter_widget_step' ) ) {
	function rigid_set_price_filter_widget_step() {
		return rigid_get_option( 'price_filter_widget_step' );
	}
}

// Price filter on category pages
if (rigid_get_option('show_pricefilter', 1) && rigid_get_option('show_refine_area')) {
	add_action('woocommerce_before_shop_loop', 'rigid_price_filter', 10);
}
if (!function_exists('rigid_price_filter')) {

	function rigid_price_filter() {
		global $wp;

		// Requires lookup table added in 3.6.
		if ( version_compare( get_option( 'woocommerce_db_version', null ), '3.6', '<' ) ) {
			return;
		}

		if ( ! is_shop() && ! is_product_taxonomy() ) {
			return;
		}

		// If there are not posts and we're not filtering, hide the widget.
		if ( ! WC()->query->get_main_query()->post_count && ! isset( $_GET['min_price'] ) && ! isset( $_GET['max_price'] ) ) { // WPCS: input var ok, CSRF ok.
			return;
		}

		wp_enqueue_style('jquery-ui');
		wp_enqueue_script( 'rigid-price-slider', get_template_directory_uri() . '/js/rigid-price-slider.js', array('jquery-ui-slider', 'wc-jquery-ui-touchpunch', 'accounting' ), false, true );

		// Round values to nearest 10 by default.
		$step = max( apply_filters( 'woocommerce_price_filter_widget_step', 10 ), 1 );

		// Find min and max price in current result set.
		$prices    = rigid_get_filtered_price();
		$min_price = $prices->min_price;
		$max_price = $prices->max_price;

		// Check to see if we should add taxes to the prices if store are excl tax but display incl.
		$tax_display_mode = get_option( 'woocommerce_tax_display_shop' );

		if ( wc_tax_enabled() && ! wc_prices_include_tax() && 'incl' === $tax_display_mode ) {
			$tax_class = apply_filters( 'woocommerce_price_filter_widget_tax_class', '' ); // Uses standard tax class.
			$tax_rates = WC_Tax::get_rates( $tax_class );

			if ( $tax_rates ) {
				$min_price += WC_Tax::get_tax_total( WC_Tax::calc_exclusive_tax( $min_price, $tax_rates ) );
				$max_price += WC_Tax::get_tax_total( WC_Tax::calc_exclusive_tax( $max_price, $tax_rates ) );
			}
		}

		$min_price = apply_filters( 'woocommerce_price_filter_widget_min_amount', floor( $min_price / $step ) * $step );
		$max_price = apply_filters( 'woocommerce_price_filter_widget_max_amount', ceil( $max_price / $step ) * $step );

		// If both min and max are equal, we don't need a slider.
		if ( $min_price === $max_price ) {
			return;
		}

		$current_min_price = isset( $_GET['min_price'] ) ? floor( floatval( wp_unslash( $_GET['min_price'] ) ) / $step ) * $step : $min_price; // WPCS: input var ok, CSRF ok.
		$current_max_price = isset( $_GET['max_price'] ) ? ceil( floatval( wp_unslash( $_GET['max_price'] ) ) / $step ) * $step : $max_price; // WPCS: input var ok, CSRF ok.

		// Remember current filters/search
		$fields = '';

		if (get_search_query()) {
			$fields .= '<input type="hidden" name="s" value="' . get_search_query() . '" />';
		}

		if (!empty($_GET['post_type'])) {
			$fields .= '<input type="hidden" name="post_type" value="' . esc_attr($_GET['post_type']) . '" />';
		}

		if (!empty($_GET['product_cat'])) {
			$fields .= '<input type="hidden" name="product_cat" value="' . esc_attr($_GET['product_cat']) . '" />';
		}

		if (!empty($_GET['product_tag'])) {
			$fields .= '<input type="hidden" name="product_tag" value="' . esc_attr($_GET['product_tag']) . '" />';
		}

		if (!empty($_GET['orderby'])) {
			$fields .= '<input type="hidden" name="orderby" value="' . esc_attr($_GET['orderby']) . '" />';
		}

		if (!empty($_GET['min_rating'])) {
			$fields .= '<input type="hidden" name="min_rating" value="' . esc_attr($_GET['min_rating']) . '" />';
		}

		if ($_chosen_attributes = WC_Query::get_layered_nav_chosen_attributes()) {
			foreach ($_chosen_attributes as $attribute => $data) {
				$taxonomy_filter = 'filter_' . str_replace('pa_', '', $attribute);

				$fields .= '<input type="hidden" name="' . esc_attr($taxonomy_filter) . '" value="' . esc_attr(implode(',', $data['terms'])) . '" />';

				if ('or' == $data['query_type']) {
					$fields .= '<input type="hidden" name="' . esc_attr(str_replace('pa_', 'query_type_', $attribute)) . '" value="or" />';
				}
			}
		}

		if ('' === get_option('permalink_structure')) {
			$form_action = remove_query_arg( array( 'page', 'paged', 'product-page' ), add_query_arg( $wp->query_string, '', home_url( $wp->request ) ) );
		} else {
			$form_action = preg_replace('%\/page/[0-9]+%', '', home_url(trailingslashit($wp->request)));
		}

		echo '<form id="rigid-price-filter-form" data-currency_pos="' . esc_attr(get_option('woocommerce_currency_pos')) . '" data-currency_symbol="' . esc_attr(get_woocommerce_currency_symbol()) . '"  method="get" action="' . esc_url($form_action) . '">
									<div id="price-filter" class="price_slider_wrapper">
										<div class="price_slider_amount" data-step="' . esc_attr( $step ) . '">
												<input type="hidden" id="min_price" name="min_price" value="' . esc_attr($current_min_price) . '" data-min="' . esc_attr($min_price) . '" placeholder="' . esc_attr__('Min price', 'rigid') . '" />
												<input type="hidden" id="max_price" name="max_price" value="' . esc_attr($current_max_price) . '" data-max="' . esc_attr($max_price) . '" placeholder="' . esc_attr__('Max price', 'rigid') . '" />
												<div class="price_label">
														<p>
																' . esc_html__('Price range:', 'rigid') . ' <span id="rigid_price_range"><span class="from"></span> &mdash; <span class="to"></span></span>
														</p>
												</div>
												' . $fields . '
												<div class="clear"></div>
										</div>
										<div class="price_slider"></div>
								</div>
						</form>';
	}

}

if (!function_exists('rigid_get_filtered_price')) {

	function rigid_get_filtered_price() {
		global $wpdb;

		$args       = WC()->query->get_main_query()->query_vars;
		$tax_query  = isset($args['tax_query']) ? $args['tax_query'] : array();
		$meta_query = isset($args['meta_query']) ? $args['meta_query'] : array();

		if ( ! is_post_type_archive( 'product' ) && ! empty( $args['taxonomy'] ) && ! empty( $args['term'] ) ) {
			$tax_query[] = WC()->query->get_main_tax_query();
		}

		foreach ( $meta_query + $tax_query as $key => $query ) {
			if (!empty($query['price_filter']) || !empty($query['rating_filter'])) {
				unset($meta_query[$key]);
			}
		}

		$meta_query = new WP_Meta_Query($meta_query);
		$tax_query = new WP_Tax_Query($tax_query);
		$search     = WC_Query::get_main_search_query_sql();

		$meta_query_sql = $meta_query->get_sql('post', $wpdb->posts, 'ID');
		$tax_query_sql = $tax_query->get_sql($wpdb->posts, 'ID');
		$search_query_sql = $search ? ' AND ' . $search : '';

		$sql = "
			SELECT min( min_price ) as min_price, MAX( max_price ) as max_price
			FROM {$wpdb->wc_product_meta_lookup}
			WHERE product_id IN (
				SELECT ID FROM {$wpdb->posts}
				" . $tax_query_sql['join'] . $meta_query_sql['join'] . "
				WHERE {$wpdb->posts}.post_type IN ('" . implode( "','", array_map( 'esc_sql', apply_filters( 'woocommerce_price_filter_post_type', array( 'product' ) ) ) ) . "')
					AND {$wpdb->posts}.post_status = 'publish'
				" . $tax_query_sql['where'] . $meta_query_sql['where'] . $search_query_sql . '
			)';

		//$sql = apply_filters( 'woocommerce_price_filter_sql', $sql, $meta_query_sql, $tax_query_sql );

		return $wpdb->get_row( $sql ); // WPCS: unprepared SQL ok.
	}

}

add_action('woocommerce_after_shop_loop', 'rigid_wrap_after_shop_loop', 5);
if (!function_exists('rigid_wrap_after_shop_loop')) {

	function rigid_wrap_after_shop_loop() {
		echo '</div>'; // closes box-products
		echo '</div>'; // closes box-products container
	}

}
add_action('woocommerce_after_shop_loop', 'rigid_shop_sidebar', 15);
if (!function_exists('rigid_shop_sidebar')) {

	function rigid_shop_sidebar() {
		echo '</div>'; // closes content_holder
		if (rigid_get_option('show_sidebar_shop') || (RIGID_IS_WOOCOMMERCE && RIGID_IS_WC_MARKETPLACE && is_tax( 'dc_vendor_shop' )) || (RIGID_IS_WOOCOMMERCE && RIGID_IS_WC_VENDORS && WCV_Vendors::is_vendor_page())) {
			do_action('woocommerce_sidebar');
			echo '<div class="clear"></div>';
		}
	}

}

// Disable the redirect on single search result
add_filter( 'woocommerce_redirect_single_search_result', '__return_false' );

add_action('woocommerce_before_shop_loop', 'rigid_wrap_before_shop_loop_after', 60);
if (!function_exists('rigid_wrap_before_shop_loop_after')) {

	function rigid_wrap_before_shop_loop_after() {
		$shop_default_product_columns = rigid_get_option('shop_default_product_columns');

		$uri_parts = explode('?', esc_url_raw($_SERVER['REQUEST_URI']), 2); // Reading only. Stripped to domain name. Used for redirection.

		$post_type_url_param = isset($_GET['post_type']) ? esc_attr($_GET['post_type']) : '';
		$rigid_search_query = get_search_query();
		$reset_params_to_keep = '';
		if($rigid_search_query && $post_type_url_param) {
			$reset_params_to_keep = '?s='.$rigid_search_query.'&post_type='.$post_type_url_param;
        } elseif ($rigid_search_query) {
			$reset_params_to_keep = '?s='.$rigid_search_query;
        } elseif ($post_type_url_param) {
			$reset_params_to_keep = '?post_type='.$post_type_url_param;
        }

        $rigid_reset_filter_url = $uri_parts[0];
		if($reset_params_to_keep) {
		    $rigid_reset_filter_url .= $reset_params_to_keep;
        }

		if (rigid_get_option('show_refine_area') && woocommerce_products_will_display()) {
		    // Define widget area here for filters
            if(is_active_sidebar('rigid_product_filters_sidebar')) {
	            echo '<div class="rigid-filter-widgets-holder">';
                    echo '<div id="rigid-filter-widgets" '. ( 'opened' == rigid_get_option('refine_area_state') ? 'class="rigid_active_filter_area"' : '' ) .' >';
                    dynamic_sidebar('rigid_product_filters_sidebar');
                    echo '</div>';
                    echo '<a href="'.esc_url($rigid_reset_filter_url).'" data-rigid_reset_query="'.esc_js($reset_params_to_keep).'" class="rigid-reset-filters">'.esc_html__('Reset All Filters', 'rigid').'</a>';
	            echo '</div>';
            }

			echo '<div class="clear"></div>';
			echo '</div>';
			echo '</div>';
		}

		echo '<div class="box-product-list">';
		echo '<div class="box-products woocommerce ' . esc_attr($shop_default_product_columns) . '">';
	}

}

// Changing products per page
add_filter('loop_shop_per_page', 'rigid_set_products_per_page', 20);

if (!function_exists('rigid_set_products_per_page')) {

	function rigid_set_products_per_page() {
		$per_page = rigid_get_option('products_per_page');
		if (array_key_exists('per_page', $_GET)) {
			$per_page = esc_attr($_GET['per_page']);
		}

		return $per_page;
	}

}

/**
 * Return the start and end sales dates for product on sale
 * If not on sale, return false
 *
 * @param type $post
 * @return boolean
 */
if (!function_exists('rigid_get_product_sales_dates')) {

	function rigid_get_product_sales_dates($post) {
		/** @var $product WC_Product */
		$start_sales_date = 9999999999;
		$end_sales_date = 0;

		$product = wc_get_product($post);
		if (!$product || !$product->is_on_sale())
			return false;

		$child_products = $product->get_children();
// If is variation product
		if (count($child_products)) {
			foreach ($child_products as $child_id) {
				$sale_price_dates_from = get_post_meta($child_id, '_sale_price_dates_from', true);
				$sale_price_dates_to = get_post_meta($child_id, '_sale_price_dates_to', true);

				if ($sale_price_dates_from && $sale_price_dates_from < $start_sales_date) {
					$start_sales_date = $sale_price_dates_from;
				}

				if ($sale_price_dates_to && $sale_price_dates_to > $end_sales_date) {
					$end_sales_date = $sale_price_dates_to;
				}
			}
		} else {
			$start_sales_date = get_post_meta($post->ID, '_sale_price_dates_from', true);
			$end_sales_date = get_post_meta($post->ID, '_sale_price_dates_to', true);
		}

		return array('from' => $start_sales_date, 'to' => $end_sales_date);
	}

}

// Show countdown for sales on product list
if (!function_exists('rigid_shop_sale_countdown')) {

	function rigid_shop_sale_countdown() {
		/**
		 * @var WC_Product $product
		 */
		global $post, $product;

		if (rigid_get_option('use_countdown', 'enabled') == 'enabled' && $product->is_on_sale()) {
			$sales_dates = rigid_get_product_sales_dates($post);
			$now = time();
			if($sales_dates['to'] && $now < $sales_dates['to']) {
                $random_num = uniqid();
                ?>
                <div class="count_holder_small" data-countdown-id="<?php echo esc_js('#rigidCountSmallLatest'.$post->ID . $random_num)?>" data-countdown-to="<?php echo esc_js(date('F j, Y G:i:s', $sales_dates['to'])) ?>">
                    <div class="count_info"><?php esc_html_e('Offer ends in', 'rigid') ?>:</div>
                    <div id="rigidCountSmallLatest<?php echo esc_attr($post->ID . $random_num) ?>"></div>
                    <div class="clear"></div>
                </div>
                <?php
            }
		}
	}

}

// Show countdown for sales on the product page
add_filter('woocommerce_single_product_summary', 'rigid_product_sale_countdown', 7);

if (!function_exists('rigid_product_sale_countdown')) {

	function rigid_product_sale_countdown() {
		global $post, $product;

		if (rigid_get_option('use_countdown', 'enabled') == 'enabled' && $product->is_on_sale()) {
			$sales_dates = rigid_get_product_sales_dates($post);
			$now = time();

			if( $sales_dates['to'] && $now < $sales_dates['to'] ){
                $unique_id = uniqid('rigid_sale_countdown');
                ?>
                <div class="count_holder"> <span class="offer_title"><?php esc_html_e('Offer ends in', 'rigid') ?>:</span>
                    <div id="<?php echo esc_attr($unique_id) ?>"></div>
                    <div class="clear"></div>
                    <?php if ($product->managing_stock()): ?>
                        <div class="count_info"><?php echo wp_kses_post(sprintf(__('Hurry! Only <b>%u</b> left', 'rigid'), $product->get_stock_quantity())) ?></div>
                    <?php endif; ?>
                    <div class="count_info_left"><?php esc_html_e('Saving', 'rigid') ?>: <b><?php echo rigid_get_product_saving($product) ?>%</b></div>
                    <div class="clear"></div>
                </div>
                <script>
                    (function ($) {
                        "use strict";
                        $(window).on("load rigid_quickview_loaded", function () {
                            $('#<?php echo esc_attr( $unique_id )?>').countdown({
                                until: new Date("<?php echo esc_js( date( 'F j, Y G:i:s', $sales_dates['to'] ) )?>"),
                                compact: false,
                                layout: '<span class="countdown_time_tiny">{dn} {dl} {hn}:{mnn}:{snn}</span>'
                            });
                        });
                    })(window.jQuery);
                </script>
                <?php
            }
		}
	}

}

// Wrap cart with div before
add_filter('woocommerce_before_cart_table', 'rigid_wrap_cart_before', 10);

if (!function_exists('rigid_wrap_cart_before')) {

	function rigid_wrap_cart_before() {
		echo '<div class="cart-info">';
	}

}

// Wrap cart with div after
add_filter('woocommerce_after_cart_table', 'rigid_wrap_cart_after', 10);

if (!function_exists('rigid_wrap_cart_after')) {

	function rigid_wrap_cart_after() {
		echo '</div>';
	}

}

// Ensure cart contents update when products are added to the cart via AJAX
add_filter('woocommerce_add_to_cart_fragments', 'rigid_header_add_to_cart_fragment');
if (!function_exists('rigid_header_add_to_cart_fragment')) {

	function rigid_header_add_to_cart_fragment($fragments) {
		ob_start();

		rigid_cart_link();

		$fragments['a.cart-contents'] = ob_get_clean();

		return $fragments;
	}

}

/**
 * Override woocommerce_taxonomy_archive_description
 * Show an archive description on taxonomy archives
 *
 * @return void
 */
function woocommerce_taxonomy_archive_description() {
	if (is_tax(array('product_cat', 'product_tag')) && get_query_var('paged') == 0) {
		$description = wpautop(do_shortcode(term_description()));

		$thumbnail_id = get_metadata( 'woocommerce_term', get_queried_object()->term_id, 'thumbnail_id', true );
		$image = wp_get_attachment_url($thumbnail_id);

		if ($description || $image) {
			if ($image) {
				$output = '<img class="pic-cat-main" src="' . esc_url($image) . '" alt="' . esc_attr(single_term_title('', false)) . '" />' . $description;
			} else {
				$output = $description;
			}

			echo '<div class="term-description fixed ' . sanitize_html_class( rigid_get_option( 'category_description_position' ) ) . '">' . $output . '</div>';
		}
	}
}

/**
 * Override the woocommerce function
 * Show a shop page description on product archives
 *
 * @subpackage	Archives
 */
function woocommerce_product_archive_description() {
	if (is_post_type_archive('product') && get_query_var('paged') == 0) {
		$shop_page = get_post(wc_get_page_id('shop'));
		if ($shop_page) {
			$description = wc_format_content($shop_page->post_content);
			if ($description) {
				echo '<div class="page-description fixed">' . $description . '</div>';
			}
		}
	}
}

// Cutting of the product title if exceeds 36 chars
if (!function_exists('rigid_short_product_title')) {

	function rigid_short_product_title($title, $short_title_length = 52) {

		if (mb_strlen($title) > $short_title_length) {
			return mb_substr($title, 0, $short_title_length - 3) . '...';
		}

		return $title;
	}

}

// Override Woocommerce Compare add link
// if Woocompare is activated
if (defined('YITH_WOOCOMPARE')) {
	global $yith_woocompare;

	$woocompareFrontEnd = $yith_woocompare->obj;
	remove_action('woocommerce_after_shop_loop_item', array($woocompareFrontEnd, 'add_compare_link'), 20);

	if (!function_exists('rigid_add_compare_link')) {

		function rigid_add_compare_link($product_id = false, $args = array()) {
			extract($args);

			global $yith_woocompare;
			$woocompareFrontEnd = $yith_woocompare->obj;

			if (!method_exists($woocompareFrontEnd, 'add_product_url')) {
				return false;
			}

			if (!$product_id) {
				global $product;
				$product_id = ($product->get_id()) && $product->exists() ? $product->get_id() : 0;
			}

			// return if product doesn't exist
			if (empty($product_id)) {
				return;
			}

			$is_button = !isset($button_or_link) || !$button_or_link ? get_option('yith_woocompare_is_button') : $button_or_link;

			if (!isset($button_text) || $button_text == 'default') {
				$button_text = get_option('yith_woocompare_button_text', esc_html__('Compare', 'rigid'));
				$button_text = function_exists('icl_translate') ? icl_translate('Plugins', 'plugin_yit_compare_button_text', $button_text) : $button_text;
			}

			printf('<a href="%s" class="%s" data-product_id="%d" title="%s"><i class="fa fa-tasks"></i></a>', esc_url($woocompareFrontEnd->add_product_url($product_id)), 'compare' . ( $is_button == 'button' ? ' button' : '' ), esc_attr($product_id), esc_attr($button_text));
		}

	}
}

// Move woocommerce_template_loop_price to be below the title
remove_action('woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10);

// If related products are set to zero hide them
if(rigid_get_option('number_related_products') == 0) {
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
}

add_filter('woocommerce_output_related_products_args', 'rigid_related_products_args');
if (!function_exists('rigid_related_products_args')) {

	/**
	 * WooCommerce Extra Feature
	 * --------------------------
	 *
	 * Change number of related products on product page
	 * Set your own value for 'posts_per_page'
	 *
	 */
	function rigid_related_products_args($args) {

		$args['posts_per_page'] = rigid_get_option('number_related_products'); // number_related_products theme option
		$args['columns'] = 1; // arranged in 1 columns

		return $args;
	}

}

add_action('woocommerce_single_product_summary', 'rigid_add_this_share', 99);
if (!function_exists('rigid_add_this_share')) {

	/**
	 * Display share links on product pages
	 */
	function rigid_add_this_share() {
		if (function_exists('rigid_share_links')) {
			rigid_share_links( get_the_title(), get_permalink());
		}
	}

}

/**
 * Cart Link
 * Displayed a link to the cart including the number of items present and the cart total
 * @param  array $settings Settings
 * @return array           Settings
 */
if (!function_exists('rigid_cart_link')) {

	function rigid_cart_link() {
		if (is_cart()) {
			$class = 'current-menu-item';
		} else {
			$class = '';
		}
		?>
		<li class="<?php echo sanitize_html_class($class); ?>">
			<a id="rigid_quick_cart_link" class="cart-contents" href="<?php echo esc_url(wc_get_cart_url()); ?>" title="<?php esc_attr_e('View your shopping cart', 'rigid'); ?>">
				<span class="count"><?php echo WC()->cart->get_cart_contents_count(); ?></span>
			</a>
		</li>
		<?php
	}

}

// Quickview ajax actions
if (!function_exists('rigid_quickview')) {

	function rigid_quickview() {
		global $post, $product, $authordata;
		$prod_id = esc_attr($_POST["productid"]);
		$post = get_post($prod_id);
		$product = wc_get_product($prod_id);
		$authordata = get_userdata($post->post_author);

		Rigid_WCVS();
		Rigid_WC_Variation_Swatches_Frontend::instance();

		if(function_exists('YITH_WCWL_Frontend')) {
			$wishlist = YITH_WCWL_Frontend();
			$wishlist->add_button();
		}

		// We also need the wp.template for this script :)
		wc_get_template( 'single-product/add-to-cart/variation.php' );
		wc_get_template('content-single-product-rigid-quickview.php');

		wp_die();
	}

}

add_action('wp_ajax_rigid_quickview', 'rigid_quickview');
add_action('wp_ajax_nopriv_rigid_quickview', 'rigid_quickview');

// Move description before title
remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20 );
add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 6 );

// Ajax add to cart on product single
if (!function_exists('rigid_wc_add_cart_ajax')) {
	function rigid_wc_add_cart_ajax() {

		$wc_notices = WC()->session->get('wc_notices');
		WC()->session->set('wc_notices', array());

		if ( is_array( $wc_notices ) ) {
			foreach ( $wc_notices as $notice_level => $notice ) {
				if ( $notice_level === 'error' ) {
					$notice_message = is_array( $notice[0] ) ? $notice[0]['notice'] : $notice[0];

					// regex to remove html tags and content
					$regex         = '/<[^>]*>[^<]*<[^>]*>/';
					$alert_message = html_entity_decode( preg_replace( $regex, '', $notice_message ) );
					$response      = array(
						'error_message' => $alert_message
					);

					wp_send_json( $response );
				}
			}
		}

		WC_AJAX::get_refreshed_fragments();

		wp_die();
	}
}

add_action('wp_ajax_rigid_wc_add_cart', 'rigid_wc_add_cart_ajax');
add_action('wp_ajax_nopriv_rigid_wc_add_cart', 'rigid_wc_add_cart_ajax');

// Force variable attributes to show below the product
add_filter( 'woocommerce_product_variation_title_include_attributes', '__return_false' );

// For the gallery images use the main image size as flexslider is disabled
add_filter( 'woocommerce_gallery_image_size', function () {
	return 'woocommerce_single';
} );

if(rigid_get_option('only_free_delivery')) {
	add_filter( 'woocommerce_package_rates', 'rigid_hide_shipping_when_free_is_available', 100 );
}

if (!function_exists('rigid_hide_shipping_when_free_is_available')) {
	/**
	 * Hide shipping rates when free shipping is available.
	 * Updated to support WooCommerce 2.6 Shipping Zones.
	 *
	 * @param array $rates Array of rates found for the package.
	 *
	 * @return array
	 */
	function rigid_hide_shipping_when_free_is_available( $rates ) {
		$free = array();
		foreach ( $rates as $rate_id => $rate ) {
			if ( 'free_shipping' === $rate->method_id ) {
				$free[ $rate_id ] = $rate;
				break;
			}
		}

		return ! empty( $free ) ? $free : $rates;
	}
}

remove_action( 'wp_ajax_mvx_edit_product_attribute', array( 'MVX_Ajax', 'edit_product_attribute_callback' ) );
add_action( 'wp_ajax_mvx_edit_product_attribute', 'rigid_mvx_edit_attribute_callback');
if (!function_exists('rigid_mvx_edit_attribute_callback')) {
	function rigid_mvx_edit_attribute_callback() {
		global $MVX;
		ob_start();

		check_ajax_referer( 'add-attribute', 'security' );

		if ( ! current_user_can( 'edit_products' ) || ( ! apply_filters( 'mvx_vendor_can_add_custom_attribute', true ) && empty( sanitize_text_field( $_POST['taxonomy'] ) ) ) ) {
			wp_die( -1 );
		}

		$i = absint( $_POST['i'] );
		$metabox_class = array();
		$attribute = new WC_Product_Attribute();

		$attribute->set_id( wc_attribute_taxonomy_id_by_name( sanitize_text_field( $_POST['taxonomy'] ) ) );
		$attribute->set_name( sanitize_text_field( $_POST['taxonomy'] ) );
		$attribute->set_visible( apply_filters( 'woocommerce_attribute_default_visibility', 1 ) );
		$attribute->set_variation( apply_filters( 'woocommerce_attribute_default_is_variation', 0 ) );

		if ( $attribute->is_taxonomy() ) {
			$metabox_class[] = 'taxonomy';
			$metabox_class[] = $attribute->get_name();
		}

		set_query_var('i', $i);
		set_query_var('metabox_class', $metabox_class);
		set_query_var('attribute', $attribute);
		get_template_part('dc-product-vendor/vendor-dashboard/product-manager/views/html-product-attribute');

		wp_die();
	}
}

add_action( 'wp_ajax_rigid_new_orders_notification', 'rigid_new_orders_notification' );
if ( ! function_exists( 'rigid_new_orders_notification' ) ) {
	function rigid_new_orders_notification() {

		if ( current_user_can( 'manage_woocommerce' ) ) {
			$order_id_to_notify       = '';
			$notified_order_ids_array = json_decode( get_option( 'rigid_last_processed_order_ids', '' ), true );
			if ( is_null( $notified_order_ids_array ) ) {
				$notified_order_ids_array = array();
			}
			$order_ids_to_be_processed_array = wc_get_orders( array( 'status' => 'processing', 'return' => 'ids' ) );

			// Clear the already notified orders which are not new any more
			$notified_order_ids_array = array_intersect( $notified_order_ids_array, $order_ids_to_be_processed_array );

			/** @var WC_Order $order */
			foreach ( $order_ids_to_be_processed_array as $order_id ) {
				if ( ! in_array( $order_id, $notified_order_ids_array ) ) {
					$order_id_to_notify = $order_id;

					break;
				}
			}

			$notification = '';
			if ( $order_id_to_notify ) {
				$notification = array(
					'title' => esc_html__( 'New Order', 'rigid' ),
					'body'  => esc_html__( 'Order', 'rigid' ) . ' #' . esc_html( $order_id_to_notify ) . ' ' . esc_html__( 'is waiting to be processed.', 'rigid' ),
					'icon'  => RIGID_IMAGES_PATH . 'order-notification.png',
					'sound'  => RIGID_IMAGES_PATH . 'cart_add.wav',
					'url'   => admin_url( 'post.php?post=' . $order_id_to_notify . '&action=edit' )
				);

				$notified_order_ids_array[] = $order_id_to_notify;
			}
			update_option( 'rigid_last_processed_order_ids', json_encode( $notified_order_ids_array ) );
			wp_send_json( $notification );
		}
		wp_die();
	}
}

// WooCommerce single product gallery type
add_action('wp', 'rigid_apply_effective_gallery_type_setting' );
if (!function_exists( 'rigid_apply_effective_gallery_type_setting' )) {
	function rigid_apply_effective_gallery_type_setting() {
		$effective_gallery_type_setting = rigid_get_effective_gallery_type_setting();

		if(in_array($effective_gallery_type_setting, array('image_list', 'mosaic_images'))) {
			remove_theme_support('wc-product-gallery-zoom');
			remove_theme_support('wc-product-gallery-slider');
		}
	}
}

if ( ! function_exists( 'rigid_get_gallery_type_classes' ) ) {
	function rigid_get_gallery_type_classes( $classes ) {
		$effective_gallery_type_setting = rigid_get_effective_gallery_type_setting();

		switch ( $effective_gallery_type_setting ) {
			case 'woo_default':
				$classes[] = 'rigid-standard-product-gallery';
				break;
			case 'image_list':
				$classes[] = 'rigid-image-list-product-gallery';
				break;
			case 'mosaic_images':
				$classes[] = 'rigid-image-list-product-gallery';
				$classes[] = 'rigid-mosaic-gallery';
				break;
		}

		return $classes;
	}
}

if (!function_exists( 'rigid_get_effective_gallery_type_setting' )) {
	function rigid_get_effective_gallery_type_setting() {
		global $post;

		$per_product_gallery_type_setting = '';
		$global_gallery_type_setting = rigid_get_option('single_product_gallery_type');

		if(is_product()) {
			$per_product_gallery_type_setting = get_post_meta($post->ID, 'rigid_single_product_gallery_type', true);
		}

		if($per_product_gallery_type_setting && $per_product_gallery_type_setting != 'default') {
			$effective_gallery_type_setting = $per_product_gallery_type_setting;
		} else {
			$effective_gallery_type_setting = $global_gallery_type_setting;
		}

		return $effective_gallery_type_setting;
	}
}

// MVX store page callback
add_action( 'mvx_before_main_content', 'rigid_mvx_before_main_content' );
if ( ! function_exists( 'rigid_mvx_before_main_content' ) ) {
	function rigid_mvx_before_main_content() {
		wc_get_template( 'global/wrapper-start.php' );
		echo '<div id="main" class="fixed box box-common">';
	}
}

add_action( 'init', 'rigid_mvx_hooks', 99 );
if ( ! function_exists( 'rigid_mvx_hooks' ) ) {
	function rigid_mvx_hooks() {
		global $MVX;
		if ( isset( $MVX->frontend ) ) {
			remove_action( 'mvx_after_main_content', array( $MVX->frontend, 'mvx_after_main_content' ) );
		}
	}
}

add_action( 'mvx_after_main_content', 'rigid_mvx_after_main_content' );
if ( ! function_exists( 'rigid_mvx_after_main_content' ) ) {
	function rigid_mvx_after_main_content() {
		wc_get_template( 'global/wrapper-end.php' );
		echo "</div>";
	}
}

add_action( 'admin_footer', 'rigid_admin_push_permission_dialog' );
if ( ! function_exists( 'rigid_admin_push_permission_dialog' ) ) {
	function rigid_admin_push_permission_dialog() {
		if ( class_exists( 'woocommerce' ) && rigid_get_option( 'order_notifications' ) ) {
			?>
            <div id="rigid-push-confirm" title="<?php esc_html_e('Push notifications for new orders by Rigid', 'rigid'); ?>">
                <p>
                    <span class="dashicons dashicons-testimonial"></span>
					<?php esc_html_e('To receive notification for new orders, you have to allow this permission in your browser.', 'rigid');?>
                </p>
            </div>
			<?php
		}
	}
}

add_filter( 'rigid_links_before_add_to_cart', 'rigid_quantity_input_on_listing' );
if ( ! function_exists( 'rigid_quantity_input_on_listing' ) ) {
	function rigid_quantity_input_on_listing() {
		if ( rigid_get_option( 'show_quantity_on_listing' ) ) {
			$product = wc_get_product( get_the_ID() );
			if ( ! $product ) {
				global $product;
			}

			if ( ! empty( $product ) && $product->is_purchasable() && ! $product->is_sold_individually() && $product->is_in_stock() && 'variable' != $product->get_type() && 'bundle' != $product->get_type() && 'combo' != $product->get_type() ) {
				woocommerce_quantity_input( [ 'min_value' => 1, 'max_value' => $product->backorders_allowed() ? '' : $product->get_stock_quantity() ] );
			}
		}
	}
}

if ( ! function_exists( 'rigid_get_visible_in_listings_meta_field_name' ) ) {
	function rigid_get_visible_in_listings_meta_field_name( $attribute_slug ): string {
		return 'attribute_' . $attribute_slug . '_listing_visibility';
	}
}

add_action( 'woocommerce_after_product_attribute_settings', 'rigid_add_visible_in_listings_checkbox', 10, 2 );
if ( ! function_exists( 'rigid_add_visible_in_listings_checkbox' ) ) {
	function rigid_add_visible_in_listings_checkbox( WC_Product_Attribute $attribute, $i ) {
		if ( defined( 'DOING_AJAX' ) ) {
			$post_id = absint( $_POST['post_id'] ?? 0 );
		} else {
			global $post;
			$post_id = $post->ID;
		}

		$value = wc_string_to_bool( get_post_meta( $post_id, rigid_get_visible_in_listings_meta_field_name( sanitize_title( $attribute->get_name() ) ), true ) );
		?>
        <tr>
            <td>
                <div class="rigid_visible_in_listings_checkbox">
                    <label><input type="checkbox" class="checkbox" <?php checked( $value, true ); ?>
                                  name="rigid_attribute_listing_visibility[<?php echo sanitize_title( $attribute->get_name() ); ?>]" value="1"/> <?php esc_html_e( 'Visible in listings', 'rigid' ); ?></label>
                </div>
            </td>
        </tr>
		<?php
	}
}

add_filter( 'woocommerce_admin_meta_boxes_prepare_attribute', 'rigid_prepare_visible_in_listings_checkbox', 10, 3 );
if ( ! function_exists( 'rigid_prepare_visible_in_listings_checkbox' ) ) {
	function rigid_prepare_visible_in_listings_checkbox( $attribute, $data, $i ) {
		if ( defined( 'DOING_AJAX' ) ) {
			check_ajax_referer( 'save-attributes', 'security' );
			if ( ! current_user_can( 'edit_products' ) || ! isset( $_POST['data'], $_POST['post_id'] ) ) {
				wp_die( - 1 );
			}

			$post_id = absint( $_POST['post_id'] );
		} else {
			global $post;
			$post_id = $post->ID;
		}

		$value = wc_string_to_bool( $data['rigid_attribute_listing_visibility'][ sanitize_title( $attribute->get_name() ) ] ?? false );
		update_post_meta( $post_id, rigid_get_visible_in_listings_meta_field_name( sanitize_title( $attribute->get_name() ) ), $value );

		return $attribute;
	}
}

if ( ! function_exists( 'rigid_display_attributes_in_listings' ) ) {
	function rigid_display_attributes_in_listings() {
		global $product;

		if ( $product ) {
			$attributes = $product->get_attributes();
			if ( ! empty( $attributes ) ) {
				?>
                <div class="rigid-attributes-in-listings">
					<?php $i = 0; ?>
					<?php /** @var WC_Product_Attribute $attribute */
					foreach ( $attributes as $attr_key => $attribute ): ?>
						<?php if ( get_post_meta( $product->get_id(), rigid_get_visible_in_listings_meta_field_name( sanitize_title( $attribute->get_name() ) ), true ) ): ?>
                            <div class="rigid-single-listing-attribute">
								<?php $terms = wc_get_product_terms( $product->get_id(), $attr_key, array( 'fields' => 'all' ) ); ?>
								<?php $attribute_options = $attribute->get_options(); ?>
								<?php if ( ! empty( $terms ) || ! empty( $attribute_options ) ): ?>
                                    <span class="rigid-listing-attribute-label"><?php echo wc_attribute_label( $attr_key ); ?></span>
									<?php rigid_display_attribute_swatches_html( $terms, $attr_key, $attribute_options ); ?>
								<?php endif; ?>
                            </div>
						<?php endif; ?>
						<?php $i ++; ?>
					<?php endforeach; ?>
                </div>
				<?php
			}
		}
	}
}

if ( ! function_exists( 'rigid_display_attribute_swatches_html' ) ) {
	function rigid_display_attribute_swatches_html( $terms, $attr_key, $attribute_options ) {
		if ( empty( $terms ) ) {
			foreach ( $attribute_options as $option ) {
				?>
                <span class="swatch swatch-label swatch-text">
                        <?php echo esc_html( $option ); ?>
                </span>
				<?php
			}
		} else {
			$extended_attribute = Rigid_WCVS()->get_tax_attribute( $attr_key );
			$attribute_type     = $extended_attribute->attribute_type ?? 'none';

			foreach ( $terms as $term ) {
				switch ( $attribute_type ) {
					case 'color' :
						$color = get_term_meta( $term->term_id, $attribute_type, true );
						?>
                        <span class="swatch swatch-color swatch-<?php echo esc_attr( $term->slug ); ?>" style="background-color:<?php echo esc_attr( $color ); ?>"
                              title="<?php echo esc_attr( $term->name ); ?>"></span>
						<?php
						break;
					case 'image':
						$image = get_term_meta( $term->term_id, $attribute_type, true );
						$image  = $image ? wp_get_attachment_image_src( $image, 'rigid-widgets-thumb' ) : '';
						$image  = $image ? $image[0] : WC()->plugin_url() . '/assets/images/placeholder.png';
						?>
                        <span class="swatch swatch-image swatch-<?php echo esc_attr( $term->slug ); ?>" title="<?php echo esc_attr( $term->name ); ?>"
                              data-value="<?php echo esc_attr( $term->slug ); ?>">
                            <img src="<?php echo esc_url( $image ); ?>" alt="<?php echo esc_attr( $term->name ); ?>">
                        </span>
						<?php
						break;
					default:
						$label = get_term_meta( $term->term_id, $attribute_type, true );
						$label  = $label ?: $term->name;
						?>
                        <span class="swatch swatch-label swatch-<?php echo esc_attr( $term->slug ); ?>" title="<?php echo esc_attr( $term->name ); ?>"
                              data-value="<?php echo esc_attr( $term->slug ); ?>"><?php echo esc_html( $label ); ?></span>
						<?php
						break;
				}
			}
		}
	}
}

add_action( 'woocommerce_grouped_product_list_before_quantity', 'rigid_grouped_product_thumbnail' );
if ( ! function_exists( 'rigid_grouped_product_thumbnail' ) ) {
	function rigid_grouped_product_thumbnail( $product ) {
		/** @var WC_Product $product */ ?>
		<?php if ( ! empty( $product->get_image_id() ) ): ?>
            <td class="rigid-grouped-product-image">
                <a href="<?php echo esc_url( $product->get_permalink() ); ?>"><?php echo wp_get_attachment_image( $product->get_image_id(), 'rigid-widgets-thumb' ); ?></a>
            </td>
		<?php endif; ?>
		<?php
	}
}