/**
 * Used for mega menu set up in admin
 */
(function ($) {
    "use strict";

    var classes_to_remove = 'rigid_is_vertical_mega rigid_is_horizontal_mega';

    var rigid_mega_menu = {
        recalcTimeout: false,

        megaMenuInitAdminUI: function (select) {
            var $container = select.parents('.menu-item:eq(0)');
            var $container_label = $container.find('span.item-type');
            var rigid_mega_menu_vertical_label = '<span class="rigid-admin-mega-menu-label"> [' + rigid_mega_menu_js_params.mega_menu_vertical_label + ']</span>';
            var rigid_mega_menu_horizontal_label = '<span class="rigid-admin-mega-menu-label"> [' + rigid_mega_menu_js_params.mega_menu_horizontal_label + ']</span>';

            if (select.val() === 'active') {
                $container.removeClass(classes_to_remove);
                $container.addClass('rigid_is_vertical_mega');
                $container_label.find('span.rigid-admin-mega-menu-label').remove();
                $container_label.html($container_label.html() + rigid_mega_menu_vertical_label);
                $container.find('.rigid-opened-home-checkbox').hide();
            } else if (select.val() === 'horizontal') {
                $container.removeClass(classes_to_remove);
                $container.addClass('rigid_is_horizontal_mega');
                $container_label.find('span.rigid-admin-mega-menu-label').remove();
                $container_label.html($container_label.html() + rigid_mega_menu_horizontal_label);
                $container.find('.rigid-opened-home-checkbox').show();
            } else {
                $container.removeClass(classes_to_remove);
                $container_label.find('span.rigid-admin-mega-menu-label').remove();
                $container.find('.rigid-opened-home-checkbox').hide();
            }
        },
        bind_click: function () {
            var megmenuActivator = '.rigid-menu-item-is_megamenu';

            $(document).on('change', megmenuActivator, function () {
                rigid_mega_menu.megaMenuInitAdminUI($(this));
                //check if anything in the dom needs to be changed to reflect the (de)activation of the mega menu
                rigid_mega_menu.recalc();
            });
        },
        recalcInit: function () {
            $(document).on('mouseup', '.menu-item-bar', function (event, ui) {
                if (!$(event.target).is('a')) {
                    clearTimeout(rigid_mega_menu.recalcTimeout);
                    rigid_mega_menu.recalcTimeout = setTimeout(rigid_mega_menu.recalc, 500);
                }
            });
        },
        recalc: function () {
            var menuItems = $('.menu-item');

            menuItems.each(function (i) {
                var item = $(this);
                var megaMenuSelect = $('.rigid-menu-item-is_megamenu', this);
                var $item_label = item.find('span.item-type');
                var rigid_column_label = '<span class="rigid-admin-mega-menu-column-label"> [' + rigid_mega_menu_js_params.column_label + ']</span>';

                if (!item.is('.menu-item-depth-0')) {
                    var checkItem = menuItems.eq(i - 1);
                    if (checkItem.is('.rigid_is_vertical_mega')) {
                        item.addClass('rigid_is_vertical_mega');
                        megaMenuSelect.val('active');
                        if (item.hasClass('menu-item-depth-1')) {
                            $item_label.find('span.rigid-admin-mega-menu-column-label').remove();
                            $item_label.html($item_label.html() + rigid_column_label);
                        }
                    } else if (checkItem.is('.rigid_is_horizontal_mega')) {
                        item.addClass('rigid_is_horizontal_mega');
                        megaMenuSelect.val('horizontal');
                        if (item.hasClass('menu-item-depth-1')) {
                            $item_label.find('span.rigid-admin-mega-menu-column-label').remove();
                            $item_label.html($item_label.html() + rigid_column_label);
                        }
                    } else {
                        item.removeClass(classes_to_remove);
                        megaMenuSelect.val('');
                        $item_label.find('span.rigid-admin-mega-menu-column-label').remove();
                    }
                }
            });

        }
    };

    $(function () {
        rigid_mega_menu.bind_click();
        rigid_mega_menu.recalcInit();
        rigid_mega_menu.recalc();
    });

    $(document).ready(function () {
        $(document.body).find('.menu-item-depth-0').find('.rigid-menu-item-is_megamenu').each(function () {
            rigid_mega_menu.megaMenuInitAdminUI($(this));
        });
        rigid_mega_menu.recalc();
    });

})(jQuery);